@@ -6,6 +6,7 @@ from django.core.management.base import BaseCommand
 from django.contrib.contenttypes.models import ContentType
 from wagtail.core.models import Page, Site
 from wagtail.images.models import Image
+from wagtail_feeds.models import RSSFeedsSettings
 
 from webspace.cms import constants
 from webspace.loader import get_model, get_class
@@ -528,6 +529,21 @@ class Command(BaseCommand):
         ws_settings.twitter = mocker.URL_TEST
         ws_settings.save()
 
+        rss = RSSFeedsSettings.for_site(site)
+        rss.feed_app_label = 'cms'
+        rss.feed_model_name = 'BlogPage'
+        rss.feed_title = 'Change me'
+        rss.feed_link = 'https://changeme.com'
+        rss.feed_description = 'Change me'
+        rss.feed_author_email = 'change@me.me'
+        rss.feed_author_link = 'https://changeme.com'
+        rss.feed_item_description_field = 'intro'
+        rss.feed_item_content_field = 'body'
+        rss.feed_image_in_content = True
+        rss.feed_item_date_field = 'date'
+        rss.is_feed_item_date_field_datetime = True
+        rss.save()
+
     def icons(self):
         keys = [
             "user",
